==> genius-0.7.7.tar.gz: genius-0.7.7/gtkextra/gtkextratypebuiltins.h <==

/* Generated data (by glib-mkenums) */

#ifndef __GTKEXTRA_TYPE_BUILTINS_H__
#define __GTKEXTRA_TYPE_BUILTINS_H__

#include <glib-object.h>

G_BEGIN_DECLS

/* enumerations from "gtkplot.h" */

GType gtk_plot_scale_get_type (void);
#define GTK_TYPE_PLOT_SCALE (gtk_plot_scale_get_type())

GType gtk_plot_symbol_type_get_type (void);
#define GTK_TYPE_PLOT_SYMBOL_TYPE (gtk_plot_symbol_type_get_type())

GType gtk_plot_symbol_style_get_type (void);
#define GTK_TYPE_PLOT_SYMBOL_STYLE (gtk_plot_symbol_style_get_type())

GType gtk_plot_border_style_get_type (void);
#define GTK_TYPE_PLOT_BORDER_STYLE (gtk_plot_border_style_get_type())

GType gtk_plot_line_style_get_type (void);
#define GTK_TYPE_PLOT_LINE_STYLE (gtk_plot_line_style_get_type())

GType gtk_plot_connector_get_type (void);
#define GTK_TYPE_PLOT_CONNECTOR (gtk_plot_connector_get_type())

GType gtk_plot_label_pos_get_type (void);
#define GTK_TYPE_PLOT_LABEL_POS (gtk_plot_label_pos_get_type())

GType gtk_plot_error_get_type (void);
#define GTK_TYPE_PLOT_ERROR (gtk_plot_error_get_type())

GType gtk_plot_orientation_get_type (void);
#define GTK_TYPE_PLOT_ORIENTATION (gtk_plot_orientation_get_type())

GType gtk_plot_axis_pos_get_type (void);
#define GTK_TYPE_PLOT_AXIS_POS (gtk_plot_axis_pos_get_type())

GType gtk_plot_label_style_get_type (void);
#define GTK_TYPE_PLOT_LABEL_STYLE (gtk_plot_label_style_get_type())

GType gtk_plot_ticks_pos_get_type (void);
#define GTK_TYPE_PLOT_TICKS_POS (gtk_plot_ticks_pos_get_type())

/* enumerations from "gtkplot3d.h" */

GType gtk_plot_plane_get_type (void);
#define GTK_TYPE_PLOT_PLANE (gtk_plot_plane_get_type())

GType gtk_plot_side_get_type (void);
#define GTK_TYPE_PLOT_SIDE (gtk_plot_side_get_type())

/* enumerations from "gtkplotbar.h" */

GType gtk_plot_bar_units_get_type (void);
#define GTK_TYPE_PLOT_BAR_UNITS (gtk_plot_bar_units_get_type())

/* enumerations from "gtkplotcanvas.h" */

GType gtk_plot_canvas_action_get_type (void);
#define GTK_TYPE_PLOT_CANVAS_ACTION (gtk_plot_canvas_action_get_type())

GType gtk_plot_canvas_flag_get_type (void);
#define GTK_TYPE_PLOT_CANVAS_FLAG (gtk_plot_canvas_flag_get_type())

GType gtk_plot_canvas_arrow_get_type (void);
#define GTK_TYPE_PLOT_CANVAS_ARROW (gtk_plot_canvas_arrow_get_type())

GType gtk_plot_canvas_selection_get_type (void);
#define GTK_TYPE_PLOT_CANVAS_SELECTION (gtk_plot_canvas_selection_get_type())

GType gtk_plot_canvas_selection_mode_get_type (void);
#define GTK_TYPE_PLOT_CANVAS_SELECTION_MODE (gtk_plot_canvas_selection_mode_get_type())

GType gtk_plot_canvas_type_get_type (void);
#define GTK_TYPE_PLOT_CANVAS_TYPE (gtk_plot_canvas_type_get_type())

GType gtk_plot_canvas_pos_get_type (void);
#define GTK_TYPE_PLOT_CANVAS_POS (gtk_plot_canvas_pos_get_type())

/* enumerations from "gtkplotcsurface.h" */

GType gtk_plot_projection_get_type (void);
#define GTK_TYPE_PLOT_PROJECTION (gtk_plot_projection_get_type())

/* enumerations from "gtkplotpc.h" */

GType gtk_plot_page_size_get_type (void);
#define GTK_TYPE_PLOT_PAGE_SIZE (gtk_plot_page_size_get_type())

GType gtk_plot_page_orientation_get_type (void);
#define GTK_TYPE_PLOT_PAGE_ORIENTATION (gtk_plot_page_orientation_get_type())

GType gtk_plot_units_get_type (void);
#define GTK_TYPE_PLOT_UNITS (gtk_plot_units_get_type())

G_END_DECLS

#endif /* __GTKEXTRA_TYPE_BUILTINS_H__ */

/* Generated data ends here */

==> genius-1.0.9.tar.gz: genius-1.0.9/gtkextra/gtkextratypebuiltins.h <==

/* Generated data (by glib-mkenums) */

#ifndef __GTKEXTRA_TYPE_BUILTINS_H__
#define __GTKEXTRA_TYPE_BUILTINS_H__

#include <glib-object.h>

G_BEGIN_DECLS
/* enumerations from "gtkplot.h" */
GType gtk_plot_scale_get_type (void);
#define GTK_TYPE_PLOT_SCALE (gtk_plot_scale_get_type())
GType gtk_plot_symbol_type_get_type (void);
#define GTK_TYPE_PLOT_SYMBOL_TYPE (gtk_plot_symbol_type_get_type())
GType gtk_plot_symbol_style_get_type (void);
#define GTK_TYPE_PLOT_SYMBOL_STYLE (gtk_plot_symbol_style_get_type())
GType gtk_plot_border_style_get_type (void);
#define GTK_TYPE_PLOT_BORDER_STYLE (gtk_plot_border_style_get_type())
GType gtk_plot_line_style_get_type (void);
#define GTK_TYPE_PLOT_LINE_STYLE (gtk_plot_line_style_get_type())
GType gtk_plot_connector_get_type (void);
#define GTK_TYPE_PLOT_CONNECTOR (gtk_plot_connector_get_type())
GType gtk_plot_label_pos_get_type (void);
#define GTK_TYPE_PLOT_LABEL_POS (gtk_plot_label_pos_get_type())
GType gtk_plot_error_get_type (void);
#define GTK_TYPE_PLOT_ERROR (gtk_plot_error_get_type())
GType gtk_plot_orientation_get_type (void);
#define GTK_TYPE_PLOT_ORIENTATION (gtk_plot_orientation_get_type())
GType gtk_plot_axis_pos_get_type (void);
#define GTK_TYPE_PLOT_AXIS_POS (gtk_plot_axis_pos_get_type())
GType gtk_plot_label_style_get_type (void);
#define GTK_TYPE_PLOT_LABEL_STYLE (gtk_plot_label_style_get_type())
GType gtk_plot_ticks_pos_get_type (void);
#define GTK_TYPE_PLOT_TICKS_POS (gtk_plot_ticks_pos_get_type())
/* enumerations from "gtkplot3d.h" */
GType gtk_plot_plane_get_type (void);
#define GTK_TYPE_PLOT_PLANE (gtk_plot_plane_get_type())
GType gtk_plot_side_get_type (void);
#define GTK_TYPE_PLOT_SIDE (gtk_plot_side_get_type())
/* enumerations from "gtkplotbar.h" */
GType gtk_plot_bar_units_get_type (void);
#define GTK_TYPE_PLOT_BAR_UNITS (gtk_plot_bar_units_get_type())
/* enumerations from "gtkplotcanvas.h" */
GType gtk_plot_canvas_action_get_type (void);
#define GTK_TYPE_PLOT_CANVAS_ACTION (gtk_plot_canvas_action_get_type())
GType gtk_plot_canvas_flag_get_type (void);
#define GTK_TYPE_PLOT_CANVAS_FLAG (gtk_plot_canvas_flag_get_type())
GType gtk_plot_canvas_selection_get_type (void);
#define GTK_TYPE_PLOT_CANVAS_SELECTION (gtk_plot_canvas_selection_get_type())
GType gtk_plot_canvas_selection_mode_get_type (void);
#define GTK_TYPE_PLOT_CANVAS_SELECTION_MODE (gtk_plot_canvas_selection_mode_get_type())
GType gtk_plot_canvas_pos_get_type (void);
#define GTK_TYPE_PLOT_CANVAS_POS (gtk_plot_canvas_pos_get_type())
/* enumerations from "gtkplotcanvasline.h" */
GType gtk_plot_canvas_arrow_get_type (void);
#define GTK_TYPE_PLOT_CANVAS_ARROW (gtk_plot_canvas_arrow_get_type())
/* enumerations from "gtkplotcanvasplot.h" */
GType gtk_plot_canvas_plot_pos_get_type (void);
#define GTK_TYPE_PLOT_CANVAS_PLOT_POS (gtk_plot_canvas_plot_pos_get_type())
/* enumerations from "gtkplotcsurface.h" */
GType gtk_plot_projection_get_type (void);
#define GTK_TYPE_PLOT_PROJECTION (gtk_plot_projection_get_type())
/* enumerations from "gtkplotpc.h" */
GType gtk_plot_page_size_get_type (void);
#define GTK_TYPE_PLOT_PAGE_SIZE (gtk_plot_page_size_get_type())
GType gtk_plot_page_orientation_get_type (void);
#define GTK_TYPE_PLOT_PAGE_ORIENTATION (gtk_plot_page_orientation_get_type())
GType gtk_plot_units_get_type (void);
#define GTK_TYPE_PLOT_UNITS (gtk_plot_units_get_type())
G_END_DECLS

#endif /* __GTKEXTRA_TYPE_BUILTINS_H__ */

/* Generated data ends here */
